summaryrefslogtreecommitdiffstats
path: root/Lib/idlelib/idle_test/test_undo.py
diff options
context:
space:
mode:
authorTerry Jan Reedy <tjreedy@udel.edu>2018-06-19 23:12:52 (GMT)
committerGitHub <noreply@github.com>2018-06-19 23:12:52 (GMT)
commit4d92158f4c3917fc4fbfebff15224e74782abf79 (patch)
treea3eea4b4e5e9d9b9b679eb538d9716758776c3bb /Lib/idlelib/idle_test/test_undo.py
parent00f9edb98dd64e14daf5c44f303deca5cbc3cdeb (diff)
downloadcpython-4d92158f4c3917fc4fbfebff15224e74782abf79.zip
cpython-4d92158f4c3917fc4fbfebff15224e74782abf79.tar.gz
cpython-4d92158f4c3917fc4fbfebff15224e74782abf79.tar.bz2
bpo-33855: Still more edits and minimal tests for IDLE (GH-7784)
Part 3 of 3, continuing PR #7689. This covers 14 idlelib modules and their tests, rpc to zoomheight except for run (already done) and tooltip (being done separately).
Diffstat (limited to 'Lib/idlelib/idle_test/test_undo.py')
-rw-r--r--Lib/idlelib/idle_test/test_undo.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/Lib/idlelib/idle_test/test_undo.py b/Lib/idlelib/idle_test/test_undo.py
index e872927..beb5b58 100644
--- a/Lib/idlelib/idle_test/test_undo.py
+++ b/Lib/idlelib/idle_test/test_undo.py
@@ -1,14 +1,13 @@
-"""Unittest for UndoDelegator in idlelib.undo.py.
+"Test undo, coverage 77%."
+# Only test UndoDelegator so far.
-Coverage about 80% (retest).
-"""
+from idlelib.undo import UndoDelegator
+import unittest
from test.support import requires
requires('gui')
-import unittest
from unittest.mock import Mock
from tkinter import Text, Tk
-from idlelib.undo import UndoDelegator
from idlelib.percolator import Percolator
@@ -131,5 +130,6 @@ class UndoDelegatorTest(unittest.TestCase):
text.insert('insert', 'foo')
self.assertLessEqual(len(self.delegator.undolist), max_undo)
+
if __name__ == '__main__':
unittest.main(verbosity=2, exit=False)